aboutsummaryrefslogtreecommitdiff
path: root/lib/inet_ntop.c
diff options
context:
space:
mode:
authorDan Fandrich <dan@coneharvesters.com>2005-12-08 22:59:58 +0000
committerDan Fandrich <dan@coneharvesters.com>2005-12-08 22:59:58 +0000
commitdf03d5a8b21a66472420116f2b3e76ba1c268a82 (patch)
treef8a3034112394443860cfbcf0e8d5f2c23a81c55 /lib/inet_ntop.c
parent6a0ed81e6795f773dbb876ec83d5c22d9504077f (diff)
Replaced nonstandard u_char and u_int types
Diffstat (limited to 'lib/inet_ntop.c')
-rw-r--r--lib/inet_ntop.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/inet_ntop.c b/lib/inet_ntop.c
index bbe837653..c3b55c02d 100644
--- a/lib/inet_ntop.c
+++ b/lib/inet_ntop.c
@@ -68,9 +68,9 @@
* Returns `dst' (as a const)
* Note:
* - uses no statics
* - takes a u_char* not an in_addr as input
*/
-static char *inet_ntop4 (const u_char *src, char *dst, size_t size)
+static char *inet_ntop4 (const unsigned char *src, char *dst, size_t size)
{
#if defined(HAVE_INET_NTOA_R_2_ARGS)
const char *ptr;
@@ -97,7 +97,7 @@ static char *inet_ntop4 (const u_char *src, char *dst, size_t size)
/*
* Convert IPv6 binary address into presentation (printable) format.
*/
-static char *inet_ntop6 (const u_char *src, char *dst, size_t size)
+static char *inet_ntop6 (const unsigned char *src, char *dst, size_t size)
{
/*
* Note that int32_t and int16_t need only be "at least" large enough
@@ -208,10 +208,10 @@ char *Curl_inet_ntop(int af, const void *src, char *buf, size_t size)
{
switch (af) {
case AF_INET:
- return inet_ntop4((const u_char*)src, buf, size);
+ return inet_ntop4((const unsigned char*)src, buf, size);
#ifdef ENABLE_IPV6
case AF_INET6:
- return inet_ntop6((const u_char*)src, buf, size);
+ return inet_ntop6((const unsigned char*)src, buf, size);
#endif
default:
SET_ERRNO(EAFNOSUPPORT);
@@ -68,9 +68,9 @@
* Note:
* - uses no statics
- * - takes a u_char* not an in_addr as input
+ * - takes a unsigned char* not an in_addr as input
*/